@@ -24,8 +24,8 @@ class OpenPYXLReader(FileHandler):
 
     def parse(self):
         if self.streams:
-            for handler, buffer in self.streams:
-                self.__parse(handler=handler, buffer=buffer)
+            for handler, buffer, kwargs in self.streams:
+                self.__parse(handler=handler, buffer=buffer, **kwargs)
         else:
             return self.__parse()
 
@@ -54,7 +54,7 @@ class OpenPYXLReader(FileHandler):
 
         return sheets
 
-    def __parse(self, handler=None, buffer=None):
+    def __parse(self, handler=None, buffer=None, **kwargs):
         from openpyxl import load_workbook
 
         xls_file = load_workbook(self.file_path)
@@ -69,7 +69,7 @@ class OpenPYXLReader(FileHandler):
                     xls_ws = xls_file[tab]
 
                     if handler:
-                        self.__openpyxl_sheet(sheet=xls_ws, handler=handler, buffer=buffer)
+                        self.__openpyxl_sheet(sheet=xls_ws, handler=handler, buffer=buffer, **kwargs)
                     else:
                         sheets[tab] = self.__openpyxl_sheet(sheet=xls_ws, handler=handler, buffer=buffer)
 
@@ -92,7 +92,7 @@ class OpenPYXLReader(FileHandler):
         if sheets:
             return sheets
 
-    def __openpyxl_sheet(self, sheet, handler=None, buffer=None):
+    def __openpyxl_sheet(self, sheet, handler=None, buffer=None, **kwargs):
         import openpyxl
 
         version = LooseVersion(get_version(openpyxl))
@@ -121,7 +121,7 @@ class OpenPYXLReader(FileHandler):
                 if handler and buffer < len(data):
                     data = self.__read_only_fix(data, version, is_readonly)
                     df = self.convert_data(data)
-                    handler(self.file_path, df, row_number - len(df) + 1, row_number)
+                    handler(self.file_path, df, row_number - len(df) + 1, row_number, **kwargs)
                     data.clear()
                     data.append(header)
                     last_row_with_data = -1
@@ -134,7 +134,7 @@ class OpenPYXLReader(FileHandler):
 
         if not df.empty and handler:
             row_number -= 1
-            handler(self.file_path, df, row_number - len(df) + 1, row_number)
+            handler(self.file_path, df, row_number - len(df) + 1, row_number, **kwargs)
         elif handler is None:
             return df
 
@@ -196,12 +196,12 @@ class ODFReader(FileHandler):
 
     def parse(self):
         if self.streams:
-            for handler, buffer in self.streams:
-                self.__parse(handler=handler, buffer=buffer)
+            for handler, buffer, kwargs in self.streams:
+                self.__parse(handler=handler, buffer=buffer, **kwargs)
         else:
             return self.__parse()
 
-    def __parse(self, handler=None, buffer=None):
+    def __parse(self, handler=None, buffer=None, **kwargs):
         from odf.opendocument import load
         from odf.table import Table
 
@@ -214,7 +214,7 @@ class ODFReader(FileHandler):
 
                 if not self.__sheet_names or tab.lower() in self.__sheet_names:
                     if handler:
-                        self.__odf_sheet(sheet=xls_ws, handler=handler, buffer=buffer)
+                        self.__odf_sheet(sheet=xls_ws, handler=handler, buffer=buffer, **kwargs)
                     else:
                         sheets[tab] = self.__odf_sheet(sheet=xls_ws, handler=handler, buffer=buffer)
         finally:
@@ -223,7 +223,7 @@ class ODFReader(FileHandler):
         if sheets:
             return sheets
 
-    def __odf_sheet(self, sheet, handler=None, buffer=None):
+    def __odf_sheet(self, sheet, handler=None, buffer=None, **kwargs):
         from odf.table import CoveredTableCell, TableCell, TableRow
 
         covered_cell_name = CoveredTableCell().qname
@@ -280,7 +280,7 @@ class ODFReader(FileHandler):
                 if handler and buffer < len(table):
                     table = self.__fix_table(table)
                     df = self.convert_data(table)
-                    handler(self.file_path, df, row_number - len(df) + 1, row_number)
+                    handler(self.file_path, df, row_number - len(df) + 1, row_number, **kwargs)
                     table.clear()
                     table.append(header)
 
@@ -291,7 +291,7 @@ class ODFReader(FileHandler):
 
         if not df.empty and handler:
             row_number -= 1
-            handler(self.file_path, df, row_number - len(df) + 1, row_number)
+            handler(self.file_path, df, row_number - len(df) + 1, row_number, **kwargs)
         elif not handler:
             return df
 
@@ -402,12 +402,12 @@ class XLRDReader(FileHandler):
 
     def parse(self):
         if self.streams:
-            for handler, buffer in self.streams:
-                self.__parse(handler=handler, buffer=buffer)
+            for handler, buffer, kwargs in self.streams:
+                self.__parse(handler=handler, buffer=buffer, **kwargs)
         else:
             return self.__parse()
 
-    def __parse(self, handler=None, buffer=None):
+    def __parse(self, handler=None, buffer=None, **kwargs):
         from xlrd import open_workbook
 
         sheets = dict()
@@ -419,7 +419,7 @@ class XLRDReader(FileHandler):
                     xls_ws = xls_file.sheet_by_name(tab)
 
                     if handler:
-                        self.__xlrd_sheet(sheet=xls_ws, handler=handler, buffer=buffer)
+                        self.__xlrd_sheet(sheet=xls_ws, handler=handler, buffer=buffer, **kwargs)
                     else:
                         sheets[tab] = self.__xlrd_sheet(sheet=xls_ws, handler=handler, buffer=buffer)
         finally:
@@ -428,7 +428,7 @@ class XLRDReader(FileHandler):
         if sheets:
             return sheets
 
-    def __xlrd_sheet(self, sheet, handler=None, buffer=None):
+    def __xlrd_sheet(self, sheet, handler=None, buffer=None, **kwargs):
         data: List[List[Scalar]] = []
         row_number = 0
         header = None
@@ -446,7 +446,7 @@ class XLRDReader(FileHandler):
 
                 if handler and len(data) <= buffer:
                     df = self.convert_data(data)
-                    handler(df, row_number - len(df) + 1, row_number)
+                    handler(df, row_number - len(df) + 1, row_number, **kwargs)
                     data.clear()
                     data.append(header)
 
@@ -456,7 +456,7 @@ class XLRDReader(FileHandler):
 
         if not df.empty and handler:
             row_number -= 1
-            handler(self.file_path, df, row_number - len(df) + 1, row_number)
+            handler(self.file_path, df, row_number - len(df) + 1, row_number, **kwargs)
         elif not handler:
             return df
 
@@ -515,12 +515,12 @@ class PYXLSBReader(FileHandler):
 
     def parse(self):
         if self.streams:
-            for handler, buffer in self.streams:
-                self.__parse(handler=handler, buffer=buffer)
+            for handler, buffer, kwargs in self.streams:
+                self.__parse(handler=handler, buffer=buffer, **kwargs)
         else:
             return self.__parse()
 
-    def __parse(self, handler=None, buffer=None):
+    def __parse(self, handler=None, buffer=None, **kwargs):
         from pyxlsb import open_workbook
 
         sheets = dict()
@@ -532,7 +532,7 @@ class PYXLSBReader(FileHandler):
                     xls_ws = xls_file.get_sheet(tab)
 
                     if handler:
-                        self.__pyxlsb_sheet(sheet=xls_ws, handler=handler, buffer=buffer)
+                        self.__pyxlsb_sheet(sheet=xls_ws, handler=handler, buffer=buffer, **kwargs)
                     else:
                         sheets[tab] = self.__pyxlsb_sheet(sheet=xls_ws, handler=handler, buffer=buffer)
         finally:
@@ -541,7 +541,7 @@ class PYXLSBReader(FileHandler):
         if sheets:
             return sheets
 
-    def __pyxlsb_sheet(self, sheet, handler, buffer):
+    def __pyxlsb_sheet(self, sheet, handler, buffer, **kwargs):
         data: List[List[Scalar]] = []
         row_number = 0
         header = None
@@ -556,7 +556,7 @@ class PYXLSBReader(FileHandler):
 
                 if handler and buffer < len(data):
                     df = self.convert_data(data)
-                    handler(self.file_path, df, row_number - len(df) + 1, row_number)
+                    handler(self.file_path, df, row_number - len(df) + 1, row_number, **kwargs)
                     data.clear()
                     data.append(header)
 
@@ -566,7 +566,7 @@ class PYXLSBReader(FileHandler):
 
         if not df.empty and handler:
             row_number -= 1
-            handler(self.file_path, df, row_number - len(df) + 1, row_number)
+            handler(self.file_path, df, row_number - len(df) + 1, row_number, **kwargs)
         elif not handler:
             return df
 
